# Almaviva | Biblioteca Python
> Biblioteca Python Almaviva com funções personalizadas para uso geral (pip install almaviva)


## Menu

Para outras informações a respeito deste projeto acesse:

- [INSTRUCTIONS.md](INSTRUCTIONS.md) - Contém instruções de uso dessa biblioteca disponibilizado no site [PyPI](https://pypi.org/project/almaviva/)
- [EDIT.md](EDIT.md) - Contém instruções para edição deste projeto
- [CONTROLE-VERSAO.md](CONTROLE-VERSAO.md) - Contém instruções para edição deste projeto
